from setuptools import setup, find_packages 
setup(name="a1lab-online-compiler", version="1.1.2", py_modules=["a1lab_cli"], entry_points={"console_scripts": ["a1lab=a1lab_cli:main"]}, author="A1Lab", description="Official CLI tool for A1Lab Online Compiler", long_description="A free interactive browser compiler for C, C++, Python, Java, and JavaScript.", long_description_content_type="text/markdown", url="https://a1lab.tech") 
